# Kubeflow SDK ROADMAP

## 2025

### Core SDK
- Release Kubeflow SDK 0.1.0 to PyPI: https://github.com/kubeflow/sdk/issues/45
- Include Kubeflow SDK into the KFP SDK: https://github.com/kubeflow/pipelines/issues/12027
- Improve test coverage: https://github.com/kubeflow/sdk/issues/16, https://github.com/kubeflow/sdk/issues/18
- Generate docs for Kubeflow SDK: https://github.com/kubeflow/sdk/issues/50

### Trainer SDK
- Migrate Trainer SDK: https://github.com/kubeflow/sdk/issues/1
- Local Execution for Training Jobs: https://github.com/kubeflow/sdk/issues/22
- Manage Kubeflow TrainJobs in a multi-cluster environment: https://github.com/kubeflow/sdk/issues/23
- Snapshot users' workspace into distributed TrainJob workload: https://github.com/kubeflow/sdk/issues/48
- Support distributed data cache configuration via initializer SDK: https://github.com/kubeflow/trainer/issues/2655
- Support other built-in trainers besides TorchTune: https://github.com/kubeflow/trainer/issues/2752

### Katib SDK
- Integrate Katib SDK: https://github.com/kubeflow/sdk/issues/46

### Model Registry SDK
- Integrate Model Registry SDK
